diff libpurple/protocols/qq/group_internal.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/group_internal.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/group_internal.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file group_internal.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -39,14 +39,14 @@
 #define QQ_GROUP_KEY_GROUP_NAME_UTF8    "group_name_utf8"
 #define QQ_GROUP_KEY_GROUP_DESC_UTF8    "group_desc_utf8"
 
-qq_group *qq_group_create_internal_record(GaimConnection *gc, 
+qq_group *qq_group_create_internal_record(PurpleConnection *gc, 
 		guint32 internal_id, guint32 external_id, gchar *group_name_utf8);
 void qq_group_delete_internal_record(qq_data *qd, guint32 internal_group_id);
 
 GHashTable *qq_group_to_hashtable(qq_group *group);
-qq_group *qq_group_from_hashtable(GaimConnection *gc, GHashTable *data);
+qq_group *qq_group_from_hashtable(PurpleConnection *gc, GHashTable *data);
 
-void qq_group_refresh(GaimConnection *gc, qq_group *group);
+void qq_group_refresh(PurpleConnection *gc, qq_group *group);
 
 void qq_set_pending_id(GSList **list, guint32 id, gboolean pending);
 GSList *qq_get_pending_id(GSList *list, guint32 id);
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.